@@ -20,6 +20,7 @@
  */
 
 #include "internal.h"
+#include <stringprep_nameprep.h>
 
 static int debug = 0;
 static int error_count = 0;
@@ -121,6 +122,10 @@ strprep[] =
   {
   "\xC2\xAA", 0, "\x61", stringprep_generic}
   ,
+  /* nameprep, exposed a bug in libstringprep 0.0.5 */
+  {
+    "\xC2\xAA\x0A", 0, "\x61\x0A", stringprep_nameprep}
+  ,
   /* unassigned code point U+0221: */
   {
     "\xC8\xA1", 0, "\xC8\xA1", stringprep_generic}
@@ -164,7 +169,10 @@ strprep[] =
   /* bidi both RandALCat and LCat  <U+0627><U+00AA><U+0628>: */
   {
     "\xD8\xA7\xC2\xAA\xD8\xA8", 0, NULL, stringprep_generic,
-    STRINGPREP_BIDI_BOTH_L_AND_RAL}
+    STRINGPREP_BIDI_BOTH_L_AND_RAL},
+  /* case mapping (this triggered a bug in 0.0.5) */
+  {
+    "CAFE", 0, "cafe", stringprep_generic}
 };
 
 int
